@@ -16,7 +16,7 @@
 #'   Default is 0.1.
 #' @param maxits Optional maximum number of iterations of the project gradient
 #'   descent algorithm for each radius. Default is 5000.
-#' @return A list
+#' @return An object of class "cv_corrected_lasso".
 #' @references \insertRef{loh2012}{hdme}
 #'
 #' \insertRef{sorensen2015}{hdme}
@@ -39,12 +39,17 @@
 #' # Run the corrected lasso
 #' cvfit <- cv_corrected_lasso(W, y, sigmaUU, no_radii = 5, n_folds = 3)
 #' plot(cvfit)
+#' print(cvfit)
 #' # Run the standard lasso using the radius found by cross-validation
-#' fit <- fit_corrected_lasso(W, y, sigmaUU, family = "gaussian",
+#' fit <- corrected_lasso(W, y, sigmaUU, family = "gaussian",
 #' radii = cvfit$radius_min)
+#' coef(fit)
+#' plot(fit)
 #' @export
 cv_corrected_lasso <- function(W, y, sigmaUU, n_folds = 10, family = "gaussian",
                  radii = NULL, no_radii = 100, alpha = 0.1, maxits = 5000){
+
+  stopifnot(family == "gaussian")
   N = nrow(W)
   y <- drop(y)
   fold_id = sample(rep(seq(n_folds), length = N))
@@ -56,7 +61,7 @@ cv_corrected_lasso <- function(W, y, sigmaUU, n_folds = 10, family = "gaussian",
 
   for(i in seq(n_folds)) {
     test = (fold_id == i)
-    outlist[[i]] <- fit_corrected_lasso(W = W[!test, , drop = FALSE], y = y[!test], sigmaUU = sigmaUU, radii = radii)
+    outlist[[i]] <- corrected_lasso(W = W[!test, , drop = FALSE], y = y[!test], sigmaUU = sigmaUU, radii = radii)
     loss[, i] <- gauss_loss(W = W[test, , drop = FALSE], y = y[test], sigmaUU = sigmaUU, beta = outlist[[i]]$betaCorr)
   }
 
@@ -80,7 +85,8 @@ cv_corrected_lasso <- function(W, y, sigmaUU, n_folds = 10, family = "gaussian",
               radius_min = radius_min,
               loss_min = loss_min,
               radius_1se = radius_1se,
-              loss_1se = loss_1se
+              loss_1se = loss_1se,
+              family = family
               )
 
   class(fit) <- c("cv_corrected_lasso")
